unit GameViewHud;

interface

uses Classes,
  CastleVectors, CastleUIControls, CastleControls, CastleKeysMouse, CastleScene, gamevariables, GameButtons, GameAnimations;

type
  TViewHud = class(TCastleView)
  published
    { Components designed using CGE editor.
      These fields will be automatically initialized at Start. }
    // ButtonXxx: TCastleButton;
    Hud: TCastleScene;
    GoForward: TCastleButton;
    GoBackward: TCastleButton;
    TurnLeft: TCastleButton;
    TurnRight: TCastleButton;
    TurnLeft2: TCastleButton;
    TurnRight2: TCastleButton;

  private
    procedure ClickForward(Sender:TObject);
    procedure ClickBackward(Sender:TObject);
    procedure ClickLeft(Sender:TObject);
    procedure ClickRight(Sender:TObject);
    procedure ClickLeft2(Sender: TObject);
    procedure ClickRight2(Sender: TObject);

  strict private
    class var FForwardCall: boolean;
    class var FBackwardCall: boolean;

    class procedure SetForwardCall(const Called: boolean); static;
    class procedure SetBackwardCall(const Called: boolean); static;



  public
    constructor Create(AOwner: TComponent); override;
    procedure Start; override;
    procedure Update(const SecondsPassed: Single; var HandleInput: boolean); override;
    procedure Wrapper;
    procedure Core;

    class property ForwardCall: boolean read FForwardCall write SetForwardCall;
    class property BackwardCall: boolean read FBackwardCall write SetBackwardCall;




  end;

var
  ViewHud: TViewHud;
  Buttons: TButtons;
  Variables: TVariables;
  Animations: TAnimations;

implementation

constructor TViewHud.Create(AOwner: TComponent);
begin
  inherited;
  DesignUrl := 'castle-data:/gameviewhud.castle-user-interface';
end;

procedure TViewHud.Start;
begin
  inherited;
  { Executed once when view starts. }
  GoForward.OnClick:={$ifdef FPC}@{$endif}ClickForward;
  GoBackward.OnClick:={$ifdef FPC}@{$endif}ClickBackward;
  TurnLeft.OnClick:={$ifdef FPC}@{$endif}ClickLeft;
  TurnRight.OnClick:={$ifdef FPC}@{$endif}ClickRight;
  TurnLeft2.OnClick:={$ifdef FPC}@{$endif}ClickLeft2;
  TurnRight2.OnClick:={$ifdef FPC}@{$endif}ClickRight2;
end;

class procedure TViewHud.SetForwardCall(const Called: boolean);
begin
  FForwardCall := Called;
end;

class procedure TViewHud.SetBackwardCall(const Called: boolean); static;
begin
  FBackwardCall := Called;
end;

procedure TViewHud.ClickForward(Sender:TObject);
begin

end;


procedure TViewHud.ClickBackward(Sender:TObject);
begin

end;

procedure TViewHud.ClickLeft(Sender:TObject);
begin

end;

procedure TViewHud.ClickRight(Sender:TObject);
begin

end;

procedure TViewHud.ClickLeft2(Sender: TObject);
begin

end;

procedure TViewHud.ClickRight2(Sender: TObject);
begin

end;

procedure TViewHud.Core;
begin
  Buttons.MF := GoForward.Pressed;
  Buttons.MB := GoBackward.Pressed;
  Buttons.L := TurnLeft.Pressed;
  Buttons.R := TurnRight.Pressed;
  Buttons.B := TurnRight2.Pressed;
  Buttons.F := TurnLeft2.Pressed;

end;

procedure TViewHud.Wrapper;
begin
   Core;
   Buttons.ToLeft := TurnLeft;
   Buttons.ToRight := TurnRight;
   Buttons.ToForward := TurnLeft2;
   Buttons.ToBack := TurnRight2;
   Buttons.MoveForward := GoForward;
   Buttons.MoveBackward := GoBackward;
end;



procedure TViewHud.Update(const SecondsPassed: Single; var HandleInput: boolean);
begin
  inherited;
  { Executed every frame. }
   Wrapper;
   Animations.Hud(Hud);
end;

end.
