{ Main view, where most of the application logic takes place.

  Feel free to use this code as a starting point for your own projects.
  This template code is in public domain, unlike most other CGE code which
  is covered by BSD or LGPL (see https://castle-engine.io/license). }
unit GameViewMain;

interface

uses Classes,
  CastleVectors, CastleComponentSerialize,
  CastleUIControls, CastleControls, CastleKeysMouse, CastleScene, CastleSceneCore,
  castleapplicationproperties, castleviewport, castlewindow, gameviewsceneone, math, LCLIntf, castlesoundengine, castlebehaviors, GameAudio;

type
  { Main view, where most of the application logic takes place. }
  TViewMain = class(TCastleView)
  published
    { Components designed using CGE editor.
      These fields will be automatically initialized at Start. }
      AppButton, SettingsButton, QuitButton, CreditsButton, HelpButton, CommunityButton, CloseSettings: TCastleButton;
      CloseHelp: TCastlebutton;
      CloseCredits: TCastlebutton;
      CloseCommunity: TCastleButton;
      ExitButton, PlayButton, Discord, Youtube: TCastleButton;
      Scene: TCastleScene;
      Credits: TCastleVerticalGroup;
      CastleButton, BlenderButton, BoscaButton, YuumiButton: TCastleButton;
      VolSlider: TCastleFloatSlider;
      Speaker: TCastleScene;
      Close, Click, Open: TCastleSound;
      SoundSource: TCastleSoundSource;

  private
  procedure ClickAppButton(Sender:TObject);
  procedure ClickSettingsButton(Sender: TObject);
  procedure ClickQuitButton(Sender: TObject);
  procedure ClickCreditsButton(Sender: TObject);
  procedure ClickPlayButton(Sender: TObject);
  procedure ClickHelp(Sender: TObject);
  procedure ClickCommunityButton(Sender: TObject);
  procedure ClickCloseSettings(Sender: TObject);
  procedure ClickCloseHelp(Sender: TObject);
  procedure ClickCloseCredits(Sender: TObject);
  procedure ClickCloseCommunity(Sender:TObject);
  procedure ClickDiscord(Sender: TObject);
  procedure ClickYoutube(Sender: TObject);
  procedure ClickCastleButton(Sender: TObject);
  procedure ClickBlenderButton(Sender:TObject);
  procedure ClickBoscaButton(Sender:TObject);
  procedure SlideVolSlider(Sender: TObject);
  procedure YUUMAA(Sender:TObject);
  procedure InitialiseButtons;
  procedure Anims;
  public
    constructor Create(AOwner: TComponent); override;
    procedure Start; override;
    procedure Update(const SecondsPassed: Single; var HandleInput: Boolean); override;
    function Press(const Event: TInputPressRelease): Boolean; override;
  end;

var
  ViewMain: TViewMain;
  AppClick, SettingsClick, CreditsClick, CommunityClick, HelpClick: Integer;
  Audio: TAudio;
implementation

uses SysUtils;

{ TViewMain ----------------------------------------------------------------- }

constructor TViewMain.Create(AOwner: TComponent);
begin
  inherited;
  DesignUrl := 'castle-data:/gameviewmain.castle-user-interface';
end;

procedure TViewMain.InitialiseButtons;
begin 
  AppButton.OnClick := {$ifdef FPC}@{$endif}ClickAppButton;
  SettingsButton.OnClick := {$ifdef FPC}@{$endif}ClickSettingsButton;
  QuitButton.OnClick := {$ifdef FPC}@{$endif}ClickQuitButton;
  CreditsButton.OnClick := {$ifdef FPC}@{$endif}ClickCreditsButton;
  PlayButton.OnClick := {$ifdef FPC}@{$endif}ClickPlayButton;
  HelpButton.OnClick := {$ifdef FPC}@{$endif}ClickHelp;
  CommunityButton.OnClick := {$ifdef FPC}@{$endif}ClickCommunityButton;
  CloseSettings.OnClick := {$ifdef FPC}@{$endif}ClickCloseSettings;
  CloseHelp.OnClick := {$ifdef FPC}@{$endif}ClickCloseHelp;
  CloseCredits.OnClick := {$ifdef FPC}@{$endif}ClickCloseCredits;
  CloseCommunity.OnClick := {$ifdef FPC}@{$endif}ClickCloseCommunity;
  Discord.OnClick := {$ifdef FPC}@{$endif}ClickDiscord;
  Youtube.OnClick := {$ifdef FPC}@{$endif}ClickYoutube;
  CastleButton.OnClick := {$ifdef FPC}@{$endif}ClickCastleButton;
  BlenderButton.OnClick := {$ifdef FPC}@{$endif}ClickBlenderButton;
  BoscaButton.OnClick := {$ifdef FPC}@{$endif}ClickBoscaButton;
  VolSlider.OnChange := {$ifdef FPC}@{$endif}SlideVolSlider;
  YuumiButton.OnClick := {$ifdef FPC}@{$endif}YUUMAA;
end;

procedure TViewMain.Start;
begin
  inherited;
  Scene.AnimationTimeSensor('SettingsPromptDoesNotExist').Start(false, true);
  Scene.AnimationTimeSensor('PlayMenuDoesNotExist').Start (false, true);
  Scene.AnimationTimeSensor('HelpMenuDoesNotExist').Start (false, true);
  Scene.AnimationTimeSensor('CommunityMenuDoesNotExist').Start (false, true);
  Scene.AnimationTimeSensor('CreditsPromptDoesNotExist').Start (false, true);
  InitialiseButtons;
  PlayButton.Exists := false;
  SettingsButton.Exists := false;
  SoundSource.Play(Open);
end;

procedure TViewMain.ClickAppButton(Sender: TObject);
begin
AppClick := AppClick + 1;
if (AppClick mod 2 = 1) then SoundEngine.Play(Click);
if (AppClick mod 2 = 0) then SoundEngine.Play(Close);
end;


procedure TViewMain.ClickSettingsButton(Sender: TObject);
begin 
SettingsClick := SettingsClick + 1;
if (SettingsClick mod 2 = 1) then SoundEngine.Play(Click);
if (SettingsClick mod 2 = 0) then SoundEngine.Play(Close);
end;

procedure TViewMain.ClickQuitButton(Sender: TObject);
begin 
  Application.Terminate;
end;

procedure TViewMain.ClickCreditsButton(Sender:TObject);
begin 
  CreditsClick := CreditsClick + 1;
if (CreditsClick mod 2 = 1) then SoundEngine.Play(Click);
if (CreditsClick mod 2 = 0) then SoundEngine.Play(Close);
end;

procedure TViewMain.ClickPlayButton(Sender: TObject);
begin 
Container.View := ViewSceneOne;
end;

procedure TViewMain.ClickHelp(Sender: TObject);
begin 
HelpClick := HelpClick + 1;
if (HelpClick mod 2 = 1) then SoundEngine.Play(Click);
if (HelpClick mod 2 = 0) then SoundEngine.Play(Close);
end;

procedure TViewMain.ClickCommunityButton(Sender: TObject);
begin 
CommunityClick := CommunityClick + 1;
if (CommunityClick mod 2 = 1) then SoundEngine.Play(Click);
if (CommunityClick mod 2 = 0) then SoundEngine.Play(Close);
end;

procedure TViewMain.ClickCloseSettings(Sender:TObject);
begin
SettingsClick := 0;
SoundEngine.Play(Close);
end;

procedure TViewMain.ClickCloseHelp(Sender:TObject);
begin 
HelpClick := 0;     
SoundEngine.Play(Close);
end;

procedure TViewMain.ClickCloseCredits(Sender: TObject);
begin 
CreditsClick := 0;    
SoundEngine.Play(Close);
end;

procedure TViewMain.ClickCloseCommunity(Sender: TObject);
begin 
CommunityClick := 0;   
SoundEngine.Play(Close);
end;

procedure TViewMain.ClickDiscord(Sender:TObject);
begin
OpenURL('https://discord.gg/eV5n8SVWeu');  
SoundEngine.Play(Click);
end;

procedure TViewMain.ClickYoutube(Sender:TObject);
begin
OpenURL('https://www.youtube.com/@haoshef');
SoundEngine.Play(Click);
end;

procedure TViewMain.ClickCastleButton(Sender:TObject);
begin
OpenURL('https://castle-engine.io/');
SoundEngine.Play(Click);
end;

procedure TViewMain.ClickBlenderButton(Sender: TObject);
begin
OpenURL('https://www.blender.org/download/');
SoundEngine.Play(Click);
end;

procedure TViewMain.ClickBoscaButton(Sender:TObject);
begin
OpenURL('https://yurisizov.itch.io/boscaceoil-blue');
SoundEngine.Play(Click);
end;

procedure TViewMain.YUUMAA(Sender: TObject);
begin
OpenURL('https://haoshef.carrd.co/');
SoundEngine.Play(Click);
end;

procedure TViewMain.SlideVolSlider(Sender:TObject);
begin
SoundEngine.Volume := VolSlider.Value;
VolSlider.Value := SoundEngine.Volume;
end;

procedure TViewMain.Anims;
begin 
      //tracking button clicks in order to return either an existent or non existent menu
//app
if ((AppClick = 1) or (AppClick mod 2 <> 0)) then begin 
Scene.AnimationTimeSensor('PlayMenuExists.001').Start (false, true);
PlayButton.Exists := true;
SettingsButton.Exists := true;
end;
if ((AppClick = 0) or (AppClick mod 2 = 0))then begin 
Scene.AnimationTimeSensor('PlayMenuDoesNotExist').Start (false, true);
PlayButton.Exists := false;
SettingsButton.Exists := false;
end;
//credits
if ((CreditsClick = 1) or (CreditsClick mod 2 <> 0)) then begin 
Scene.AnimationTimeSensor('CreditsPromptExists').Start(false,true);
CloseCredits.Exists := true;
Credits.Exists := true;
CastleButton.Exists := true;
end;
if ((CreditsClick = 0) or (CreditsClick mod 2 = 0)) then begin 
Scene.AnimationTimeSensor('CreditsPromptDoesNotExist').Start(false, true);
CloseCredits.Exists := false;
Credits.Exists := false;
CastleButton.Exists := false;
end;
//settings
if ((SettingsClick = 1) or (SettingsClick mod 2 <> 0)) then begin 
Scene.AnimationTimeSensor('SettingsPromptExists').Start (false, true);
CloseSettings.Exists := true;
Speaker.Exists := true;
VolSlider.Exists := true;
end;
if ((SettingsClick = 0) or (SettingsClick mod 2 = 0)) then begin
Scene.AnimationTimeSensor('SettingsPromptDoesNotExist').Start (false, true);
CloseSettings.Exists := false;
Speaker.Exists := false;
VolSlider.Exists := false;
end;
//community
if ((CommunityClick = 1) or (CommunityClick mod 2 <> 0)) then begin 
Scene.AnimationTimeSensor('CommunityMenuExists').Start (false, true);
CloseCommunity.Exists := true;
Discord.Exists := true;
Youtube.Exists := true;
end;
if ((CommunityClick = 0) or (CommunityClick mod 2 = 0)) then begin 
Scene.AnimationTimeSensor('CommunityMenuDoesNotExist').Start (false, true);
CloseCommunity.Exists := false; 
Discord.Exists := false;
Youtube.Exists := false;
end;
//help
if ((HelpClick = 1) or (HelpClick mod 2 <> 0)) then begin 
Scene.AnimationTimeSensor('HelpMenuExists').Start (false, true);
CloseHelp.Exists := true;
end;
if ((HelpClick = 0) or (HelpClick mod 2 = 0)) then begin 
Scene.AnimationTimeSensor('HelpMenuDoesNotExist').Start (false, true);
CloseHelp.Exists := false;
end;
end;

procedure TViewMain.Update(const SecondsPassed: Single; var HandleInput: Boolean);
begin
  inherited;
  { This virtual method is executed every frame (many times per second). }
  Anims;
end;

function TViewMain.Press(const Event: TInputPressRelease): Boolean;
begin
  Result := inherited;
  if Result then Exit; // allow the ancestor to handle keys

  { This virtual method is executed when user presses
    a key, a mouse button, or touches a touch-screen.

    Note that each UI control has also events like OnPress and OnClick.
    These events can be used to handle the "press", if it should do something
    specific when used in that UI control.
    The TViewMain.Press method should be used to handle keys
    not handled in children controls.
  }

  // Use this to handle keys:
  {
  if Event.IsKey(keyXxx) then
  begin
    // DoSomething;
    Exit(true); // key was handled
  end;
  }
end;

end.
