unit GameViewOffice;

interface

uses Classes,
  CastleVectors, CastleUIControls, CastleControls, CastleKeysMouse, CastleCameras, CastleScene, GameRegulation, GameMovement, CastleWindow, CastleTransform, CastleViewport, GameVariables;

type
  TViewOffice = class(TCastleView)
  published
    { Components designed using CGE editor.
      These fields will be automatically initialized at Start. }
    // ButtonXxx: TCastleButton;
    Hud: TCastleDesign;
    Nav: TCastleWalkNavigation;
    Camera: TCastleCamera;
    Dialogue: TCastleButton;
    Viewport: TCastleViewport;
    ChatBox: TCastleImageControl;
    Boss: TCastleScene;

  private
    var Clicks: integer;
    procedure ClickDialogue(Sender:TObject);
    procedure DialogueWorkings;


  public
    constructor Create(AOwner: TComponent); override;
    procedure Start; override;
    procedure Update(const SecondsPassed: Single; var HandleInput: boolean); override;
  end;

var
  ViewOffice: TViewOffice;
  Movement: TMovement;
  Variables: TVariables;
  Regulation: TGameRegulation;

implementation

uses gameviewhud;

constructor TViewOffice.Create(AOwner: TComponent);
begin
  inherited;
  DesignUrl := 'castle-data:/gameviewoffice.castle-user-interface';
end;

procedure TViewOffice.Start;
begin
  inherited;
  { Executed once when view starts. }
  Dialogue.OnClick := {$ifdef FPC}@{$endif}ClickDialogue;
  Variables.HP := 5;
  Movement.Nav := Nav;
  Movement.Camera := Camera;
  Regulation.InitAddOn;
  Clicks := 0;
  ChatBox.Exists := true;
  Boss.AnimationTimeSensor('1').Start(false, true);
end;

procedure TViewOffice.ClickDialogue(Sender:TObject);
begin
   Clicks := Clicks + 1;
end;

procedure TViewOffice.DialogueWorkings;
begin
  if Clicks = 1 then begin
    Boss.PlayAnimation('2',false, true);
  end;
  if Clicks = 2 then begin
     Boss.PlayAnimation('3',false, true);
  end;
  if Clicks = 3 then begin
     Boss.PlayAnimation('4', false, true);
  end;
  if Clicks = 4 then begin
     ChatBox.Exists := false;
    Container.PushView(ViewHud);
  end;
end;

procedure TViewOffice.Update(const SecondsPassed: Single; var HandleInput: boolean);
begin
  inherited;

  { Executed every frame. }
  Regulation.AddOn;
  DialogueWorkings;




end;

end.
